==> wpackagist-plugin-complianz-gdpr-premium-5.0.0.7.zip: pro/config/includes.php <==
<?php
defined( 'ABSPATH' ) or die( "you do not have acces to this page!" );

require_once( cmplz_path . '/pro/config/steps.php' );
require_once( cmplz_path . '/pro/config/questions-wizard.php' );
require_once( cmplz_path . '/pro/config/documents/documents.php' );
require_once( cmplz_path . '/pro/config/EU/questions-dataleak.php' );
require_once( cmplz_path . '/pro/config/US/questions-dataleak.php' );
require_once( cmplz_path . '/pro/config/CA/questions-dataleak.php' );
require_once( cmplz_path . '/pro/config/UK/questions-dataleak.php' );
require_once( cmplz_path . '/pro/config/EU/questions-processing.php' );
require_once( cmplz_path . '/pro/config/US/questions-processing.php' );
require_once( cmplz_path . '/pro/config/CA/questions-processing.php' );
require_once( cmplz_path . '/pro/config/UK/questions-processing.php' );
require_once( cmplz_path . '/pro/config/dynamic-fields.php' );
require_once( cmplz_path . '/pro/config/dynamic-document-elements.php' );
require_once( cmplz_path . '/pro/config/documents/US/dataleak-report.php' );
require_once( cmplz_path . '/pro/config/documents/US/privacy-policy.php' );
require_once( cmplz_path . '/pro/config/documents/US/processing-agreement.php' );
require_once( cmplz_path . '/pro/config/documents/US/privacy-policy-children.php' );
require_once( cmplz_path . '/pro/config/documents/CA/dataleak-report.php' );
require_once( cmplz_path . '/pro/config/documents/CA/privacy-policy.php' );
require_once( cmplz_path . '/pro/config/documents/CA/processing-agreement.php' );
require_once( cmplz_path . '/pro/config/documents/CA/privacy-policy-children.php' );
require_once( cmplz_path . '/pro/config/documents/disclaimer.php' );
require_once( cmplz_path . '/pro/config/documents/EU/privacy-policy.php' );
require_once( cmplz_path . '/pro/config/documents/EU/processing-agreement.php' );
require_once( cmplz_path . '/pro/config/documents/EU/dataleak-report.php' );
require_once( cmplz_path . '/pro/config/documents/EU/impressum.php' );
require_once( cmplz_path . '/pro/config/documents/UK/privacy-policy.php' );
require_once( cmplz_path . '/pro/config/documents/UK/processing-agreement.php' );
require_once( cmplz_path . '/pro/config/documents/UK/dataleak-report.php' );
require_once( cmplz_path . '/pro/config/documents/UK/privacy-policy-children.php' );
require_once( cmplz_path . '/pro/records-of-consent/class-records-of-consent.php' );

==> wpackagist-plugin-complianz-gdpr-premium-5.1.3.1.zip: pro/config/includes.php <==
<?php
defined( 'ABSPATH' ) or die( "you do not have acces to this page!" );

require_once( cmplz_path . '/pro/config/steps.php' );
require_once( cmplz_path . '/pro/config/questions-wizard.php' );
require_once( cmplz_path . '/pro/config/documents/documents.php' );
require_once( cmplz_path . '/pro/config/EU/questions-dataleak.php' );
require_once( cmplz_path . '/pro/config/US/questions-dataleak.php' );
require_once( cmplz_path . '/pro/config/CA/questions-dataleak.php' );
require_once( cmplz_path . '/pro/config/UK/questions-dataleak.php' );
require_once( cmplz_path . '/pro/config/AU/questions-dataleak.php' );
require_once( cmplz_path . '/pro/config/EU/questions-processing.php' );
require_once( cmplz_path . '/pro/config/US/questions-processing.php' );
require_once( cmplz_path . '/pro/config/CA/questions-processing.php' );
require_once( cmplz_path . '/pro/config/UK/questions-processing.php' );
require_once( cmplz_path . '/pro/config/AU/questions-processing.php' );
require_once( cmplz_path . '/pro/config/dynamic-fields.php' );
require_once( cmplz_path . '/pro/config/dynamic-document-elements.php' );
require_once( cmplz_path . '/pro/config/documents/US/dataleak-report.php' );
require_once( cmplz_path . '/pro/config/documents/US/privacy-policy.php' );
require_once( cmplz_path . '/pro/config/documents/US/processing-agreement.php' );
require_once( cmplz_path . '/pro/config/documents/US/privacy-policy-children.php' );
require_once( cmplz_path . '/pro/config/documents/CA/dataleak-report.php' );
require_once( cmplz_path . '/pro/config/documents/CA/privacy-policy.php' );
require_once( cmplz_path . '/pro/config/documents/CA/processing-agreement.php' );
require_once( cmplz_path . '/pro/config/documents/CA/privacy-policy-children.php' );
require_once( cmplz_path . '/pro/config/documents/disclaimer.php' );
require_once( cmplz_path . '/pro/config/documents/EU/privacy-policy.php' );
require_once( cmplz_path . '/pro/config/documents/EU/processing-agreement.php' );
require_once( cmplz_path . '/pro/config/documents/EU/dataleak-report.php' );
require_once( cmplz_path . '/pro/config/documents/EU/impressum.php' );
require_once( cmplz_path . '/pro/config/documents/UK/privacy-policy.php' );
require_once( cmplz_path . '/pro/config/documents/UK/processing-agreement.php' );
require_once( cmplz_path . '/pro/config/documents/UK/dataleak-report.php' );
require_once( cmplz_path . '/pro/config/documents/UK/privacy-policy-children.php' );
require_once( cmplz_path . '/pro/config/documents/AU/privacy-policy.php' );
require_once( cmplz_path . '/pro/config/documents/AU/processing-agreement.php' );
require_once( cmplz_path . '/pro/config/documents/AU/dataleak-report.php' );
require_once( cmplz_path . '/pro/config/documents/AU/privacy-policy-children.php' );
require_once( cmplz_path . '/pro/records-of-consent/class-records-of-consent.php' );
